@@ -49,7 +49,7 @@ Imager, Imager::Filter::DynTest
 
 =head1 AUTHOR
 
-Tony Cook <tony@imager.perl.org>
+Tony Cook <tonyc@cpan.org>
 
 =cut
 
